@@ -1,7 +1,7 @@
 import unittest
 from .testcase import BulbsTestCase
 from bulbs.model import Node, NodeProxy, Relationship, RelationshipProxy
-from bulbs.property import Integer, String, DateTime, Bool
+from bulbs.property import Integer, String, DateTime
 from bulbs.utils import current_datetime
 
 class Knows(Relationship):
@@ -16,7 +16,6 @@ class Person(Node):
     
     name = String(nullable=False)
     age  = Integer()
-    is_adult = Bool()
 
 
 
@@ -26,14 +25,13 @@ class NodeTestCase(BulbsTestCase):
         indices = self.vertex_index_proxy(self.index_class,self.client)
         self.people = NodeProxy(Person,self.client)
         self.people.index = indices.get_or_create("person")
-        self.james = self.people.create(name="James", age=34, is_adult=True)
+        self.james = self.people.create(name="James", age=34)
 
     def test_properties(self):
         #assert type(self.james.eid) == int
         assert self.james.element_type == "person"
         assert self.james.name == "James"
         assert self.james.age == 34
-        assert self.james.is_adult is True
 
     def test_get(self):
         person = self.people.get(self.james.eid)
@@ -59,15 +57,10 @@ class NodeTestCase(BulbsTestCase):
 class RelationshipTestCase(BulbsTestCase):
 
     def setUp(self):
-        indicesV = self.vertex_index_proxy(self.index_class,self.client)
-        indicesE = self.edge_index_proxy(self.index_class,self.client)
-
+        indices = self.vertex_index_proxy(self.index_class,self.client)
         self.people = NodeProxy(Person,self.client)
-        self.people.index = indicesV.get_or_create("people")
-
         self.knows = RelationshipProxy(Knows,self.client)
-        self.knows.index = indicesE.get_or_create("knows")
-
+        self.people.index = indices.get_or_create("people")
         self.james = self.people.create(name="James", age=34)
         self.julie = self.people.create(name="Julie", age=28)
         
